@@ -2,6 +2,7 @@ package Test2;
 use strict;
 use warnings;
 
+use Test2::Global();
 use Test2::Context();
 use Test2::Context::Trace();
 use Test2::Hub::Subtest();
@@ -10,10 +11,9 @@ use Test2::Hub::Interceptor::Terminator();
 
 use Carp qw/croak confess longmess/;
 use Scalar::Util qw/weaken blessed/;
-use Test2::Util qw/get_tid try/;
+use Test2::Util qw/get_tid/;
 
-use vars qw/$VERSION/;
-$Test2::VERSION = 0.000005;
+our $VERSION = 0.000006;
 
 our @EXPORT_OK = qw{
     context
@@ -66,6 +66,8 @@ sub context {
     _depth_error($current, [$pkg, $file, $line, $sub, $depth])
         if $current;
 
+    # Directly bless the object here, calling new is a noticable performance
+    # hit with how often this needs to be called.
     my $dbg = bless(
         {
             frame => [$pkg, $file, $line, $sub],
@@ -75,6 +77,8 @@ sub context {
         'Test2::Context::Trace'
     );
 
+    # Directly bless the object here, calling new is a noticable performance
+    # hit with how often this needs to be called.
     $current = bless(
         {
             stack  => $stack,
@@ -143,8 +147,8 @@ sub intercept(&) {
     my $ctx = context();
 
     my $ipc;
-    if ($INC{'Test2/IPC.pm'}) {
-        my ($driver) = Test2::IPC->drivers;
+    if (my $global_ipc = Test2::Global->ipc) {
+        my $driver = blessed($global_ipc);
         $ipc = $driver->new;
     }
 
@@ -158,12 +162,17 @@ sub intercept(&) {
 
     $ctx->stack->top; # Make sure there is a top hub before we begin.
     $ctx->stack->push($hub);
-    my ($ok, $err) = try {
-        $code->(
-            hub => $hub,
-            context => $ctx->snapshot,
-        );
-    };
+
+    # Do not use 'try' cause it localizes __DIE__, and does not preserve $@
+    # or $!
+    my ($ok, $err);
+    {
+        local $@ = $@;
+        local $! = int($!);
+        $ok = eval { $code->(hub => $hub, context => $ctx->snapshot); 1 };
+        $err = $@;
+    }
+
     $hub->cull;
     $ctx->stack->pop($hub);
 
@@ -205,7 +214,12 @@ sub run_subtest {
 
     my ($ok, $err, $finished);
     TS_SUBTEST_WRAPPER: {
-        ($ok, $err) = try { $code->(@args) };
+        # Do not use 'try' cause it localizes __DIE__, and does not preserve $@
+        # or $!
+        local $@ = $@;
+        local $! = int($!);
+        $ok = eval { $code->(@args); 1 };
+        $err = $@;
 
         # They might have done 'BEGIN { skip_all => "whatever" }'
         if (!$ok && $err =~ m/Label not found for "last TS_SUBTEST_WRAPPER"/) {
@@ -343,7 +357,7 @@ active context one will be generated. When a context is generated it will
 default to using the file and line number where the currently running sub was
 called from.
 
-Please see the L</"CRITICAL DETAILS"> section for important rools about what
+Please see L<Test2::Context/"CRITICAL DETAILS"> for important rules about what
 you can and acannot do with a context once it is obtained.
 
 B<Note> This function will throw an exception if you ignore the context object
@@ -483,7 +497,7 @@ will be run as a subtest. A subtest is an isolated test state that is condensed
 into a single L<Test2::Event::Subtest> event, which contains all events
 generated inside the subtest.
 
-Arguments:
+=head3 ARGUMENTS:
 
 =over 4
 
